==> haskell-attoparsec-iso8601-1.1.0.0-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec-iso8601
version:              1.1.0.0
visibility:           public
id:                   attoparsec-iso8601-1.1.0.0-42jdj1qyB31Y4UuqI7WWd
key:                  attoparsec-iso8601-1.1.0.0-42jdj1qyB31Y4UuqI7WWd
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  4e14de728b53d79146d151f68126b04e
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/attoparsec-iso8601-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/attoparsec-iso8601-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.0.0-42jdj1qyB31Y4UuqI7WWd
depends:
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    base-compat-batteries-0.12.2-DZODtHbvxbMGx8Y8Jpq12e text-1.2.5.0
    time-1.11.1.1 time-compat-1.9.6.1-9frNG8JeBK9CzdNhWglkk

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.1.0.0-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 attoparsec-iso8601
version:              1.1.0.0
visibility:           public
id:                   attoparsec-iso8601-1.1.0.0-Ly8MkRQGXIJAeLpodwi8Tg
key:                  attoparsec-iso8601-1.1.0.0-Ly8MkRQGXIJAeLpodwi8Tg
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  794299720d1b470d8abbb4df86d2a419
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/attoparsec-iso8601-1.1.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/attoparsec-iso8601-1.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.0.0-Ly8MkRQGXIJAeLpodwi8Tg
depends:
    attoparsec-0.14.4-IUoeEKVn7Gr6GqDDI9lyTI base-4.16.4.0
    base-compat-batteries-0.12.2-Hlzktlwsu2M7guzl1w4Dz3 text-1.2.5.0
    time-1.11.1.1 time-compat-1.9.6.1-HEeLlSu8aB57PQ9XcXxOia

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
